# Project Description
### A cross platform Python package to automate sending and receiving of WhatsApp messages

## Functions
```python
    newMessagesThere(self)
    getNewMessages(self)
    sendMessage(self, personal_or_grp, message_to, message_type, text, image_location)
    sendMultipleMessages(self, list_of_replies)
    getPreviousMessages(self, count, personal_or_grp, ph_no_or_name, message_type, start_date_time, end_date_time)
```
### Full Documentation Link 
[https://whatsappbotdocs.readthedocs.io/en/latest/](https://whatsappbotdocs.readthedocs.io/en/latest/)

### Author
[Nanda Kishore B](https://github.com/nandakishfast)

### Other Contributors
[Arvindram K](https://github.com/ArvindR07) - Documentation
[Niresh K](https://github.com/21-niresh-21) - Setup

### Mentor
[Dr. Bagavathi Sivakumar P](https://scholar.google.co.in/citations?user=vrMN16EAAAAJ&hl=en)
